@@ -65,7 +65,7 @@ USERS = {
         'uid': 42413,
         'gid': 42413,
     },
-    'freezer-user': {
+    'freezer-user': {  # unused user (freezer dropped)
         'uid': 42414,
         'gid': 42414,
     },
@@ -133,7 +133,7 @@ USERS = {
         'uid': 42432,
         'gid': 42432,
     },
-    'murano-user': {
+    'murano-user': {  # unused user (murano dropped)
         'uid': 42433,
         'gid': 42433,
     },
@@ -161,15 +161,15 @@ USERS = {
         'uid': 42440,
         'gid': 42440,
     },
-    'sahara-user': {
+    'sahara-user': {  # unused user (sahara dropped)
         'uid': 42441,
         'gid': 42441,
     },
-    'senlin-user': {
+    'senlin-user': {  # unused user (senlin dropped)
         'uid': 42443,
         'gid': 42443,
     },
-    'solum-user': {
+    'solum-user': {  # unused user (solum dropped)
         'uid': 42444,
         'gid': 42444,
     },
@@ -213,7 +213,7 @@ USERS = {
         'uid': 42457,
         'gid': 42457,
     },
-    'vitrage-user': {
+    'vitrage-user': {  # unused user (vitrage dropped)
         'uid': 42459,
         'gid': 42459,
     },
