@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
@@ -102,13 +100,7 @@ def handle_repos(context, reponames, mode):
             repo_data[name] = params
 
     base_package_type = context.get('base_package_type')
-
     base_distro = context.get('base_distro')
-
-    if (base_distro == 'centos' and
-            context.get('base_distro_tag', 'stream8').startswith('stream9')):
-        base_distro = "centos9"
-
     base_arch = context.get('base_arch')
 
     commands = ''
@@ -134,6 +126,11 @@ def handle_repos(context, reponames, mode):
 >>/etc/apt/sources.list.d/{repo}.sources \
 && echo 'Signed-By: /etc/kolla/apt-keys/{repo_list[repo]['gpg_key']}' \
 >>/etc/apt/sources.list.d/{repo}.sources \
+&& """
+                    if repo_list[repo]['arch']:
+                        commands += f"""echo 'Architectures: \
+{repo_list[repo]['arch']}' \
+>>/etc/apt/sources.list.d/{repo}.sources \
 && """
         except KeyError:
             # NOTE(hrw): we ignore missing repositories for a given
