@@ -55,7 +55,7 @@ class MethodsTest(base.TestCase):
         result = methods.handle_repos(template_vars, ['grafana', 'ceph'],
                                       'enable')
         expectCmd = 'RUN dnf config-manager  --enable grafana '
-        expectCmd += '--enable centos-ceph-quincy || true'
+        expectCmd += '--enable centos-ceph-reef || true'
         self.assertEqual(expectCmd, result)
 
     def test_enable_repos_debian(self):
@@ -86,13 +86,13 @@ class MethodsTest(base.TestCase):
         }
 
         result = methods.handle_repos(template_vars, ['rabbitmq'], 'enable')
-        expectCmd = "RUN echo 'Uris: https://ppa1.novemberain.com/rabbitmq/rabbitmq-server/deb/debian' "  # noqa: E501
+        expectCmd = "RUN echo 'Uris: https://ppa1.rabbitmq.com/rabbitmq/rabbitmq-server/deb/debian' "  # noqa: E501
         expectCmd += ">/etc/apt/sources.list.d/rabbitmq.sources && "
         expectCmd += "echo 'Components: main' "
         expectCmd += ">>/etc/apt/sources.list.d/rabbitmq.sources && "
         expectCmd += "echo 'Types: deb' "
         expectCmd += ">>/etc/apt/sources.list.d/rabbitmq.sources && "
-        expectCmd += "echo 'Suites: bullseye' "
+        expectCmd += "echo 'Suites: bookworm' "
         expectCmd += ">>/etc/apt/sources.list.d/rabbitmq.sources && "
         expectCmd += "echo 'Signed-By: /etc/kolla/apt-keys/rabbitmq.gpg' "
         expectCmd += ">>/etc/apt/sources.list.d/rabbitmq.sources && "
@@ -133,13 +133,13 @@ class MethodsTest(base.TestCase):
         expectCmd += ">>/etc/apt/sources.list.d/grafana.sources && "
 
         expectCmd += "echo 'Uris: "
-        expectCmd += "https://ppa1.novemberain.com/rabbitmq/rabbitmq-server/deb/debian' "  # noqa: E501
+        expectCmd += "https://ppa1.rabbitmq.com/rabbitmq/rabbitmq-server/deb/debian' "  # noqa: E501
         expectCmd += ">/etc/apt/sources.list.d/rabbitmq.sources && "
         expectCmd += "echo 'Components: main' "
         expectCmd += ">>/etc/apt/sources.list.d/rabbitmq.sources && "
         expectCmd += "echo 'Types: deb' "
         expectCmd += ">>/etc/apt/sources.list.d/rabbitmq.sources && "
-        expectCmd += "echo 'Suites: bullseye' "
+        expectCmd += "echo 'Suites: bookworm' "
         expectCmd += ">>/etc/apt/sources.list.d/rabbitmq.sources && "
         expectCmd += "echo 'Signed-By: /etc/kolla/apt-keys/rabbitmq.gpg' "
         expectCmd += ">>/etc/apt/sources.list.d/rabbitmq.sources"
@@ -167,7 +167,7 @@ class MethodsTest(base.TestCase):
         result = methods.handle_repos(template_vars, ['grafana', 'ceph'],
                                       'disable')
         expectCmd = 'RUN dnf config-manager  --disable grafana '
-        expectCmd += '--disable centos-ceph-quincy || true'
+        expectCmd += '--disable centos-ceph-reef || true'
         self.assertEqual(expectCmd, result)
 
     # NOTE(hrw): there is no disabling of repos for Debian/Ubuntu
